'use strict';
const bodyEmpty = require('./bodyEmpty');
const htmlCombinatorCommentBody = require('./htmlCombinatorCommentBody');
const htmlFirstChild = require('./htmlFirstChild');
const important = require('./important');
const leadingStar = require('./leadingStar');
const leadingUnderscore = require('./leadingUnderscore');
const mediaSlash0 = require('./mediaSlash0');
const mediaSlash0Slash9 = require('./mediaSlash0Slash9');
const mediaSlash9 = require('./mediaSlash9');
const slash9 = require('./slash9');
const starHtml = require('./starHtml');
const trailingSlashComma = require('./trailingSlashComma');

module.exports = [
  bodyEmpty,
  htmlCombinatorCommentBody,
  htmlFirstChild,
  important,
  leadingStar,
  leadingUnderscore,
  mediaSlash0,
  mediaSlash0Slash9,
  mediaSlash9,
  slash9,
  starHtml,
  trailingSlashComma,
];
